#
# spec file for package jts
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jts
Version:        1.20.0
Release:        1.2
Summary:        Java Topology Suite
License:        EPL-1.0
Group:          Development/Libraries/Java
URL:            https://projects.eclipse.org/projects/locationtech.%{name}
Source0:        https://github.com/locationtech/%{name}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.googlecode.json-simple:json-simple)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:  mvn(org.jdom:jdom2)
BuildArch:      noarch

%description
The LocationTech JTS Topology Suite (JTS) is an open source Java software
library that provides an object model for planar geometry together with a
set of fundamental geometric functions. JTS conforms to the Simple Features
Specification for SQL published by the Open GIS Consortium.  JTS is designed
to be used as a core component of vector-based geomatics software such as
geographical information systems. It can also be used as a general-purpose
library providing algorithms in computational geometry.

%package app
Summary:        JTS Applications & tools
Group:          Development/Libraries/Java

%description app
Applications & tools for working with JTS.

%package example
Summary:        JTS Examples
Group:          Development/Libraries/Java

%description example
Examples of working JTS code.

%package io
Summary:        JTS IO
Group:          Development/Libraries/Java

%description io
Extension to assist in read / write operations.

%package parent
Summary:        JTS Parent POMs
Group:          Development/Libraries/Java

%description parent
Maven POMs for project inheritance.

%package lab
Summary:        JTS Lab
Group:          Development/Libraries/Java

%description lab
Algorithms for JTS which are exploratory or in-progress

%package build-tools
Summary:        JTS Build Tools
Group:          Development/Libraries/Java

%description build-tools
JTS Topology Suite Build Configuration

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
This package contains API documentation for %{name}.

%package doc
Summary:        Documentation for %{name}
Group:          Development/Libraries/Java

%description doc
This package contains documentation for %{name}.

%prep
%setup -q

# Uneeded plugins for RPM builds
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-release-plugin
%pom_remove_plugin :maven-pmd-plugin
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :maven-site-plugin

# Don't bundle deps
%pom_remove_plugin :maven-assembly-plugin modules/tests modules/app

# Backward compatibility aliases
%{mvn_alias} org.locationtech.jts:jts-core com.vividsolutions:jts-core com.vividsolutions:jts
%{mvn_alias} org.locationtech.jts.io:jts-io-common com.vividsolutions:jts-io

%{mvn_package} ":jts-io*" jts-io
%{mvn_package} ":jts-lab*" jts-lab
%{mvn_package} ":jts{,-modules}" jts-parent
%{mvn_package} ":jts-tests" jts-app

%build
%{mvn_build} -sfj -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8 org.apache.maven.plugins:maven-javadoc-plugin:aggregate

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}
install -dm0755 %{buildroot}%{_defaultdocdir}/%{name}
cp README.md USING.md MIGRATION.md doc/* %{buildroot}%{_defaultdocdir}/%{name}

%files -f .mfiles-%{name}-core
%license LICENSE*

%files app -f .mfiles-%{name}-app

%files example -f .mfiles-%{name}-example

%files io -f .mfiles-%{name}-io

%files lab -f .mfiles-%{name}-lab

%files build-tools -f .mfiles-build-tools

%files parent -f .mfiles-%{name}-parent
%license LICENSE*

%files javadoc -f .mfiles-javadoc
%license LICENSE*

%files doc
%license LICENSE*
%{_defaultdocdir}/%{name}

%changelog
* Sun Sep 15 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to version 1.20.0
  * New Features
    + Add CoverageValidator CoveragePolygonValidator (#900)
    + Add CoverageGapFinder (#900)
    + Add CoverageUnion (#900)
    + Add CoverageSimplifier (#911)
    + Add OverlayNG support for simple GeometryCollection inputs
    (#915)
    + Add Geometry.hasDimension(int dim) method (#944)
    + Add ConcaveHull.alphaShape function (#952)
    + Add OffsetCurve Joined mode (#956)
    + Add PointLocation.isOnSegment function (#1048)
    + Add RelateNG API for improved topological relationship
    functionality and performance (#1052, #1055)
    + Add system property jts.relate=ng to enable use of RelateNG
    in Geometry methods (#1073)
  * Functionality Improvements
    + Improve TopologyPreservingSimplifier to prevent edge-disjoint
    line collapse (#925)
    + Improve OffsetCurve to return more linework for some input
    situations (#956)
    + Reduce buffer curve short fillet segments (#960)
    + Added ability to specify boundary for LargestEmptyCircle
    (#973)
    + Improve DouglaPeuckerSimplifier and
    TopologyPreservingSimplifier to handle ring endpoints (#1013)
    + Add Angle functions sinSnap and cosSnap to avoid small
    errors, e.g. with buffer operations (#1016)
    + Improve Buffer input simplification for rings (#1022)
    + Improve CoverageSimplifier with ring removal, smoothing,
    inner/outer and per-feature tolerances (#1060)
  * Bug Fixes
    + Fix WKBReader and WKBWriter handling of M measures when
    writing to WKB and reading from WKB (#734)
    + Fix PreparedGeometry handling of EMPTY elements (#904)
    + Fix WKBReader parsing of WKB containing multiple empty
    elements (#905)
    + Fix LineSegment.orientationIndex(LineSegment) to correct
    orientation for non-collinear segments on right (#914)
    + Fix DepthSegment compareTo method (#920)
    + Ensure GeometryFixer does not change coordinate dimension
    (#922)
    + Improve ConvexHull radial sort robustness (#927)
    + Improve robustness of Delaunay Triangulation frame size
    heuristic (#931)
    + Fix PreparedLineString.intersects to handle mixed GCs
    correctly (#944)
    + Fix QuadEdgeSubdivision.TriangleEdgesListVisitor (#945)
    + Fix PolygonHoleJoiner to handle all valid inputs (allows
    PolygonTriangulator, ConstrainedDelaunayTriangulator, and
    ConcaveHullOfPolygons to work correctly) (#946)
    + Fix OffsetCurve handling of input with repeated points (#956)
    + Fix OffsetCurve handling zero offset distance (#971)
    + Fix MaximumInscribedCircle and LargestEmptyCircle to avoid
    long looping for thin inputs (#978)
    + Fix OffsetCurve to use a minimum QuadrantSegs value (#981)
    + Fix HilbertEncoder Y extent handling
    + Fix Geometry.getCoordinate to return non-null coordinate for
    collections with empty first element (#987)
    + Fix LargestEmptyCircle to handle polygonal obstacles (#988)
    + Make intersection computation more robust (#989)
    + Fix VariableBuffer to handle zero vertex buffer distances
    correctly (#997)
    + Fix IncrementalDelaunayTriangulator to ensure triangulation
    boundary is convex (#1004)
    + Fix OverlayNG Area Check heuristic for difference (#1005)
    + Fix InteriorPointPoint to handle empty elements
    + Fix DistanceOp for empty elements (#1010)
    + Fix predicates for MultiPoint with EMPTY (#1015)
    + Fix InteriorPoint for MultiLineString with EMPTY (#1023)
    + Fix TopologyPreservingSimplifier to prevent incorrect
    topology from jumping components (#1024)
    + Fix OffsetCurve to ensure end segments are included (#1029)
    + Fix PointLocator to respect BoundaryNodeRule for single lines
    (#1031)
    + Fix BufferOp Inverted Ring Removal check (#1038)
    + Improve VariableBuffer segment buffer cap generation (#1041)
    + Fix TopologyPreservingSimplifier ring endpoint removal
    indexing (#1059)
  * Performance Improvements
    + Improve Polygonizer performance in some cases with many
    islands (#906)
    + Improve Convex Hull performance by avoiding duplicate
    uniquing (#985)
    + Improve HPRtree performance (#1012)
    + Improve performance of noding and overlay via HPRtree (#1012)
    + Improve DistanceOp performance for Point-Point (#1049)
    + Improve CoveragePolygonValidator via section performance
    optimization (#1053)
* Wed Sep 13 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to version 1.19.0
  * New Features
    + Add ConstrainedDelaunayTriangulator and PolygonTriangulator
    (#775, #862)
    + Add Tri data structure for representing triangulations (#775)
    + Add DiscreteFrechetDistance (#764, #783)
    + Add OffsetCurve class (#810, #816)
    + Add ConcaveHull class for points (#823, #829)
    + Add ConcaveHullOfPolygons class (#870)
    + Add PolygonHullSimplifier class (#861, #880)
    + TWKB read and write implementation (#854)
  * Functionality Improvements
    + Improve GeometryFixer behaviour for holes outside polygons
    (#772)
    + Simplify and fix logic of BufferParameters.setQuadSegs (#778)
    + Improve KdTree query code to avoid recursion (#779)
    + Add KdTree seeding toSnappingNoder (#780)
    + Add GeometryFixer option to preserve Multi geometry types
    when collapses occur (#791)
    + Make QuadTree thread-safe (#792)
    + Allow specifying a fixed PrecisionModel via grid size (#804)
    + Improve Densifier to interpolate Z values (#835)
    + Add support for GeoJSON Feature and FeatureCollection types
    (#837)
    + Add WKTReader.setFixStructure to fix WKT input (#848)
    + Improve LineSegment.hashCode to reduce collisions (#872)
  * Performance Improvements
    + Improve performance of CoveageUnion by using boundary chains
    (#891)
  * Bug Fixes
    + Fix WKTReader geometry typename parsing (#786)
    + Fix CoordinateArrays.reverse to handle zero-length arrays
    [#787]
    + Fix GeometryFixer to appply isKeepCollapsed flag to
    GeometryCollection elements (#790)
    + Fix RectangleIntersects to handle XYZM geometry (#794)
    + Fix various operations to handle XYZM geometry (#795)
    + Fix SnapRoundingNoder to use tolerance in noding (also fixes
    GeometryPrecisionReducer) (#802)
    + Fix MaximumInscribedCircle to avoid infinite-looping on flat
    collapsed input (#807)
    + Add OverlayNG result area heuristic check (#812)
    + Fix the buffers generated for mitred joins (#818)
    + Fix WKTReader to produce correct XY coordinate dimension for
    POLYGON EMPTY (#828)
    + Fix RelateOp for a snapped line boundary point (#839)
    + Fix IsValidOp for repeated node points (#845)
    + Fix IsSimpleOp for repeated endpoints (#851)
    + Fix GeometryFixer via noding check for zero-distance buffers
    (#867)
    + Fix MinimumDiameter.minimumRectangle for flat inputs (#875)
    + Fix BufferOp inverted ring check optimization (#878)
    + Fix STRtree nearest-neighbour queries on empty trees to avoid
    NPE (#886)
    + Remove transitive compile dependency on junit from
    jts-io-commmon (#855)
* Wed Sep 13 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Thu May  5 2022 Fridrich Strba <fstrba@suse.com>
- Force generating javadoc with maven-javadoc-plugin, since the
  xmvn javadoc mojo is crashing on this package
* Fri Jun 11 2021 Anton Shvetz <shvetz.anton@gmail.com>
- Update to version 1.18.1
- Package documentation in a separate package
* Tue Sep  8 2020 Matthias Mailänder <mailaender@opensuse.org>
- initial version of 1.17.1
